==> pdepend_2.5.2.orig.tar.gz: pdepend-2.5.2/src/main/php/PDepend/Source/AST/ASTConstantDeclarator.php <==
<?php
/**
 * This file is part of PDepend.
 *
 * PHP Version 5
 *
 * Copyright (c) 2008-2017 Manuel Pichler <mapi@pdepend.org>.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *   * Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *
 *   * Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 *
 *   * Neither the name of Manuel Pichler nor the names of his
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * @copyright 2008-2017 Manuel Pichler. All rights reserved.
 * @license http://www.opensource.org/licenses/bsd-license.php BSD License
 */

namespace PDepend\Source\AST;

use PDepend\Source\ASTVisitor\ASTVisitor;

/**
 * This class represents a single constant declarator within a constant
 * definition.
 *
 * <code>
 * class Foo
 * {
 *     //    --------
 *     const BAR = 42;
 *     //    --------
 * }
 * </code>
 *
 * Or in a comma separated constant defintion:
 *
 * <code>
 * class Foo
 * {
 *     //    --------
 *     const BAR = 42,
 *     //    --------
 *
 *     //    --------------
 *     const BAZ = 'Foobar',
 *     //    --------------
 *
 *     //    ----------
 *     const FOO = 3.14;
 *     //    ----------
 * }
 * </code>
 *
 * @copyright 2008-2017 Manuel Pichler. All rights reserved.
 * @license http://www.opensource.org/licenses/bsd-license.php BSD License
 */
class ASTConstantDeclarator extends AbstractASTNode
{
    /**
     * The initial declaration value for this node or <b>null</b>.
     *
     * @var \PDepend\Source\AST\ASTValue
     */
    protected $value = null;

    /**
     * Returns the initial declaration value for this node.
     *
     * @return \PDepend\Source\AST\ASTValue
     */
    public function getValue()
    {
        return $this->value;
    }

    /**
     * Sets the declared default value for this constant node.
     *
     * @param  \PDepend\Source\AST\ASTValue $value
     * @return void
     */
    public function setValue(ASTValue $value)
    {
        $this->value = $value;
    }

    /**
     * Accept method of the visitor design pattern. This method will be called
     * by a visitor during tree traversal.
     *
     * @param \PDepend\Source\ASTVisitor\ASTVisitor $visitor
     * @param mixed $data
     * @return mixed
     * @since  0.9.12
     */
    public function accept(ASTVisitor $visitor, $data = null)
    {
        return $visitor->visitConstantDeclarator($this, $data);
    }

    /**
     * Magic sleep method that returns an array with those property names that
     * should be cached for this node instance.
     *
     * @return array(string)
     */
    public function __sleep()
    {
        return array_merge(array('value'), parent::__sleep());
    }
}

==> pdepend_2.8.0.orig.tar.gz: pdepend-2.8.0/src/main/php/PDepend/Source/AST/ASTConstantDeclarator.php <==
<?php
/**
 * This file is part of PDepend.
 *
 * PHP Version 5
 *
 * Copyright (c) 2008-2017 Manuel Pichler <mapi@pdepend.org>.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *   * Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *
 *   * Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 *
 *   * Neither the name of Manuel Pichler nor the names of his
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * @copyright 2008-2017 Manuel Pichler. All rights reserved.
 * @license http://www.opensource.org/licenses/bsd-license.php BSD License
 */

namespace PDepend\Source\AST;

use PDepend\Source\ASTVisitor\ASTVisitor;

/**
 * This class represents a single constant declarator within a constant
 * definition.
 *
 * <code>
 * class Foo
 * {
 *     //    --------
 *     const BAR = 42;
 *     //    --------
 * }
 * </code>
 *
 * Or in a comma separated constant defintion:
 *
 * <code>
 * class Foo
 * {
 *     //    --------
 *     const BAR = 42,
 *     //    --------
 *
 *     //    --------------
 *     const BAZ = 'Foobar',
 *     //    --------------
 *
 *     //    ----------
 *     const FOO = 3.14;
 *     //    ----------
 * }
 * </code>
 *
 * @copyright 2008-2017 Manuel Pichler. All rights reserved.
 * @license http://www.opensource.org/licenses/bsd-license.php BSD License
 */
class ASTConstantDeclarator extends AbstractASTNode
{
    /**
     * The initial declaration value for this node or <b>null</b>.
     *
     * @var \PDepend\Source\AST\ASTValue
     */
    protected $value = null;

    /**
     * Returns the initial declaration value for this node.
     *
     * @return \PDepend\Source\AST\ASTValue
     */
    public function getValue()
    {
        return $this->value;
    }

    /**
     * Sets the declared default value for this constant node.
     *
     * @param  \PDepend\Source\AST\ASTValue $value
     * @return void
     */
    public function setValue(ASTValue $value)
    {
        $this->value = $value;
    }

    /**
     * Accept method of the visitor design pattern. This method will be called
     * by a visitor during tree traversal.
     *
     * @param \PDepend\Source\ASTVisitor\ASTVisitor $visitor
     * @param mixed $data
     * @return mixed
     * @since  0.9.12
     */
    public function accept(ASTVisitor $visitor, $data = null)
    {
        return $visitor->visitConstantDeclarator($this, $data);
    }

    /**
     * Magic sleep method that returns an array with those property names that
     * should be cached for this node instance.
     *
     * @return array<string>
     */
    public function __sleep()
    {
        return array_merge(array('value'), parent::__sleep());
    }
}
